<?php

namespace ReadyApp\ExampleApp;


class ExportReport2Excel {

    /**
     * @param ReportView $report
     * @param int        $userId
     *
     * @return void
     * @throws \Exception
     */
    public function execute(ReportView $report, int $userId): void {
        require_once(MOD_PATH.'Reports/services/ReportsService.inc');

        $reportFilename = NULL;
        $path = NULL;
        $api = new \EDokApi();

        try {
            $sr = new \ReportsService();
            $path = $sr->exportToXLS($report->getId(), $report->getTableViewName(), FALSE, FALSE, NULL, $reportFilename);
        } catch (\WidgetException $e) {
            $api->notifyUser([
                'usr_id' => $userId,
                'msgtxt' => sprintf(\Translator::translate('Wystąpił błąd podczas eksportu raportu: %s'), $e->getMessage()),
            ]);
        }

        try {
            $doc_id = $api->createDocument([
                'dscrpt' => sprintf(\Translator::translate('Wydruk raport do pliku %s'), $reportFilename),
                'dctptp' => 'Note',
                'adduid' => $userId,
            ]);

            if ($doc_id) {
                $fileContent = file_get_contents($path);
                $api->addAttachmentToDocument($fileContent, $reportFilename, $doc_id, 'binary');

                $api->notifyUser([
                    'usr_id' => $userId,
                    'type__' => 'Communicator',
                    'msgtxt' => \Translator::translate('Raport został już wyeksportowany do pliku XLS'),

                    'nscls_' => 'DOCUMENT',
                    'nskey_' => $doc_id,
                    'nstxt_' => sprintf(\Translator::translate('Pobierz plik %s'), $reportFilename),
                ]);
            }
        } catch (\Exception $e) {
            $api->notifyUser([
                'usr_id' => $userId,
                'msgtxt' => sprintf(\Translator::translate('Wystąpił błąd podczas tworzenia dokumentu z plikiem: %s'), $e->getMessage()),
            ]);
        }

    }
}